<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Validators;
use Illuminate\Support\Facades\Validator;
use App\Managers\User\UserModel;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Hash;

class AuthValidator
{
    public function __construct()
    {
        $this->userModel = new UserModel();
    }
    
    public function register($data)
    {
        $validation = $validator = Validator::make(
                ['Name'             => $data['name'],
                 'Email'            => $data['email'],
                 'Dob'              => $data['dob'],
                 'Password'         => $data['password'],
                 'Confirm Password' => $data['confirm_password'],
                 'Address'          => $data['address'],
                 'City'             => $data['city'],
                 'Country'          => $data['country']],
                ['Name'             => 'required',
                 'Email'            => 'required|email',
                 'Dob'              => 'required|date_format:d M Y',
                 'Password'         => 'required|min:6',
                 'Confirm Password' => 'required|min:6',
                 'Address'          => 'required',
                 'City'             => 'required',
                 'Country'          => 'required']
        );
        if ($validation->fails())
        {
            $errors = $validation->errors();
            $errors = $errors->toArray();
            
            foreach($errors AS $error)
            {
                $return['errors'][] = $error;
            }
            return $return;
        }
        
        if($data['password'] != $data['confirm_password'])
        {
            $return['errors'][] = 'Password and confirm password Does not match';
            return $return;
            exit;
        }
        
        $user = $this->userModel->where('email', $data['email'])->first();
        if($user)
        {
            $return['errors'][] = 'The email is already registered with our database';
            return $return;
            exit;
        }
    }
    
    public function login($data)
    {
        $validation = $validator = Validator::make(
                ['Email'            => $data['email'],
                 'Password'         => $data['password']],
                ['Email'            => 'required|email',
                 'Password'         => 'required|min:6']
        );
        if ($validation->fails())
        {
            $errors = $validation->errors();
            $errors = $errors->toArray();
            
            foreach($errors AS $error)
            {
                $return['errors'][] = $error;
            }
            return $return;
        }
    }
    
    public function resetPassword($data)
    {
        $validation = $validator = Validator::make(
                ['Password'            => $data['password'],
                 'Confirm Password'         => $data['confirmPassword']],
                ['Password'            => 'required|min:6',
                 'Confirm Password'         => 'required|min:6']
        );
        if ($validation->fails())
        {
            $errors = $validation->errors();
            $errors = $errors->toArray();
            
            foreach($errors AS $error)
            {
                $return['errors'][] = $error;
            }
            return $return;
        }
        
        if($data['password'] != $data['confirmPassword'])
        {
            $return['errors'][] = 'Password and COnfirm Password Does Not Match';
            return $return;
        }
    }
    
    public function resetPasswordMain($data)
    {
        $validation = $validator = Validator::make(
                ['Current Password'     => trim($data['currentPassword']),
                 'New Password'         => trim($data['newPassword']),
                 'Confirm Password'     => trim($data['confirmPassword'])],
                ['Current Password'     => 'required|min:6',
                 'New Password'         => 'required|min:6',
                 'Confirm Password'     => 'required|min:6']
        );
        if ($validation->fails())
        {
            $errors = $validation->errors();
            $errors = $errors->toArray();
            
            foreach($errors AS $error)
            {
                $return['errors'][] = $error;
            }
            return $return;
        }
        
        if($data['newPassword'] != $data['confirmPassword'])
        {
            $return['errors'][] = array('Password and Confirm Password Does not Match');
        }
        
        $user = $this->userModel->where('UUID', Session::get('admin'))->where('password', Hash::make($data['currentPassword']))->first();
        if(!$user)
        {
            $return['errors'][] = array('Current Password Does not Match');
        }
    }
}